from .factory                        import GetInput


def start_wish():
    """
        Run the Factory Class.
        Goes through the logic. Pass one employee at the time from the scheduler and send emails
        Here is an example code:

        {
            "id": 228,
            "name": "Karey",
            "lastname": "Boros",
            "dateOfBirth": "1970-07-02T00:00:00",
            "employmentStartDate": "2004-07-01T00:00:00",
            "employmentEndDate": null
        }
    """

    print("\n**************** Wishes Selections *****************\n")
    print("Please select: ** ONLY BIRTHDAY WISHES SELECTION IS ACCEPTED AT THE MOMENT")
    print("\t 1. Birthday Wishes")
    print("\t 2. Anniversary Wishes")

    INPUT = GetInput(input("Enter your selection:   "))
    INPUT.get_input_redirect()


if __name__ == '__main__':
    start_wish()



import os
import pathlib

import requests
from os                                         import path

from .core.mail                                 import SendWishEmail
from .db.data                                   import JSONData
from .core.employee                             import Employee
from .operation                                 import Operation as ops
from .core.process                              import ProcessEmployee



class GetInput:
    current_date = ops.get_today_date()

    def __init__(self, selection):
        self.selection   = selection
        self.emp_list    = []
        self.emp_na_list = []
    
    def compare_api_and_local_data(self):
        for employee in self.employees_local:
            if self.worker['id'] == employee['id']:
                str_date = ''
                lastNotification     = employee.get('lastNotification')
                lastBirthdayNotified = employee.get('lastBirthdayNotified')
                if lastNotification:
                    str_date = lastNotification
                elif lastBirthdayNotified:
                    str_date = lastBirthdayNotified

                if str_date:
                    last_date = ops.str_to_date(str_date)
                    if self.current_date.month == last_date.month and self.current_date.day == last_date.day:
                        return True
        return False

    def call_real_endpoint(self):

        employees     = []
        exc_employees = []
        emp_resp      = requests.get('https://interview-assessment-1.realmdigital.co.za/employees')
        exc_emp_resp  = requests.get('https://interview-assessment-1.realmdigital.co.za/do-not-send-birthday-wishes')

        if emp_resp.status_code == 200:
            employees = emp_resp.json()
        if exc_emp_resp.status_code == 200:
            exc_employees = exc_emp_resp.json()

        data = {
            'employees'     : employees,
            'exc_employees' : exc_employees
        }

        return data

    def get_input_redirect(self):

        birthday_names       = []
        anniversary_names    = []
        self.employees_local = []

        data_api      = self.call_real_endpoint()
        employees_api = data_api['employees']
        employees     = employees_api

        current_dir = pathlib.Path(__file__).parent
        json_file   = f'{current_dir}/db/employeesZ.json'

        if path.isfile(json_file):
            data_local           = JSONData(None, None, None)
            self.employees_local = data_local.extract_employee_data(json_file)
            # employees = self.employees_local

        # BIRTHDAY WISHES
        if self.selection == '1':
            for worker in employees:
                self.worker = worker

                if self.compare_api_and_local_data():
                    continue

                employee = Employee(self.worker, employees)
                is_valid = ProcessEmployee(employee).validate_employee_to_receive_msg()

                if is_valid:
                    # BirthdayMessage(employee)
                    birthday_names.append(employee.name)
                    print(employee.name)
                    self.worker['lastNotification']     = employee.get_current_date.strftime('%Y-%m-%d')
                    self.worker['lastBirthdayNotified'] = employee.get_current_date.strftime('%Y-%m-%d')
                    self.emp_list.append(self.worker)
                else:
                    self.emp_na_list.append(self.worker)

            if birthday_names:
                SendWishEmail(self.selection, birthday_names).start()

            if self.emp_list:
                JSONData(self.emp_list, None, 'Y', self.emp_list, None).start()

            if self.emp_na_list:
                JSONData(None, self.emp_na_list, 'N', None, self.emp_na_list).start()

        # ANNIVERSARY WISHES
        if self.selection == '2':
            for worker in employees:
                self.worker = worker

                if self.compare_api_and_local_data():
                    continue

                employee = Employee(self.worker, employees)
                is_valid = ProcessEmployee(employee).validate_employee_to_receive_msg()

                if is_valid:
                    # AnniversaryMessage(employee)
                    anniversary_names.append(employee.name)
                    self.worker['lastNotification']     = employee.get_current_date.strftime('%Y-%m-%d')
                    self.worker['lastBirthdayNotified'] = employee.get_current_date.strftime('%Y-%m-%d')
                    self.emp_list.append(self.worker)
                else:
                    self.emp_na_list.append(self.worker)

            if anniversary_names:
                SendWishEmail(self.selection, anniversary_names).start()

            if self.emp_list:
                JSONData(self.emp_list, None, 'Y', self.emp_list, None).start()

            if self.emp_na_list:
                JSONData(None, self.emp_na_list, 'N', None, self.emp_na_list).start()

        return



from setuptools                         import setup, find_packages


setup(
    name='realmz',
    version='0.0.13',
    license='MIT',
    author='Billy Katalayi',
    author_email='billysbn7@gmail.com',
    description="To send birthday wishes to employees",
    long_description='''
    A service component that will send birthday wishes to employees. The service extracts a list of employees whose birthdays occur today using the Realm Digital Employee API
and create a generic message E.g. “Happy Birthday {name 1}, {name 2}” and send the message to an email address configured for the component. https://interview-assessment-1.realmdigital.co.za/
    ''',
    packages=find_packages('src'),
    package_dir={'' : 'src'},
    url='https://github.com/Billykat7/wishes',
    keywords='employees birthday, anniversary automated wishes',
    project_urls = {
        "Bug Tracker": 'https://github.com/Billykat7/wishes/issues',
    },
    classifiers = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        # 'celery',
        'python-dotenv',
        # 'redis',
        'requests',
        'SQLAlchemy'
    ],
    include_package_data=True,
    python_requires = ">=3.6"
)
